==> risk-center-api-0.5.36-lj-20200511.103623-12-sources.jar: cn/com/duiba/tuia/risk/center/api/remoteservice/RemoteDomainService.java <==
package cn.com.duiba.tuia.risk.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.risk.center.api.common.PageResultDto;
import cn.com.duiba.tuia.risk.center.api.dto.domain.DomainDTO;
import cn.com.duiba.tuia.risk.center.api.dto.req.domain.PagingDomainParam;

import java.util.List;

/**
 * 域名服务
 *
 * @author peanut.huang
 * @date 2019/10/23
 * @since JDK 1.8
 */
@AdvancedFeignClient
public interface RemoteDomainService {

    /**
     * 域名分页查询
     *
     * @param pagingDomainParam  查询参数
     * @return
     */
    PageResultDto<DomainDTO> pagingList(PagingDomainParam pagingDomainParam);

    /**
     * 添加域名
     *
     * @param domainDTO      域名参数
     * @throws  BizException
     * @return
     */
    boolean addDomain(DomainDTO domainDTO) throws BizException;

    /**
     * 删除域名
     *
     * @param  id   域名记录id
     * @return
     * @throws BizException
     */
    boolean deleteDomain(Long id) throws BizException;

    /**
     * 根据域名类型查询有效域名列表
     *
     * @param domainType  域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    List<String> selectValidDomainByType(Integer domainType);

    /**
     * 查询给微信巡查的域名列表
     *
     * @return
     */
    List<String> selectWxPatrol();

    /**
     * 根据域名查询
     *
     * @param domain   域名
     * @return
     */
    DomainDTO selectByDomain(String domain);

    /**
     * 根据策略id 和域名类型查询替换域名
     * @param advertId   广告id
     * @param domainType 域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    String getReplaceDomain(Long advertId, Integer domainType);

    /**
     * 根据域名类型查询有效域名列表
     *
     * @param domainType  域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    List<DomainDTO> getValidDomainByType(Integer domainType);

    /**
     * 根据域名策略更新域名到新的策略
     * @param strategyId
     * @param newStrategyId
     * @return
     */
    Integer updateDomainStrategy(Long strategyId, Long newStrategyId);

}

==> risk-center-api-0.5.54-lj-20201105.085721-5-sources.jar: cn/com/duiba/tuia/risk/center/api/remoteservice/RemoteDomainService.java <==
package cn.com.duiba.tuia.risk.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.risk.center.api.common.PageResultDto;
import cn.com.duiba.tuia.risk.center.api.dto.domain.DomainDTO;
import cn.com.duiba.tuia.risk.center.api.dto.req.domain.DomainDealParam;
import cn.com.duiba.tuia.risk.center.api.dto.req.domain.PagingDomainParam;

import java.util.List;
import java.util.Set;

/**
 * 域名服务
 *
 * @author peanut.huang
 * @date 2019/10/23
 * @since JDK 1.8
 */
@AdvancedFeignClient
public interface RemoteDomainService {

    /**
     * 域名分页查询
     *
     * @param pagingDomainParam  查询参数
     * @return
     */
    PageResultDto<DomainDTO> pagingList(PagingDomainParam pagingDomainParam);

    /**
     * 添加域名
     *
     * @param domainDTO      域名参数
     * @throws  BizException
     * @return
     */
    boolean addDomain(DomainDTO domainDTO) throws BizException;

    /**
     * 更新域名
     *
     * @param domainDTO      域名参数
     * @throws  BizException
     * @return
     */
    boolean updateDomain(DomainDTO domainDTO) throws BizException;

    /**
     * 删除域名
     *
     * @param  id   域名记录id
     * @return
     * @throws BizException
     */
    boolean deleteDomain(Long id) throws BizException;

    /**
     * 根据域名类型查询有效域名列表
     *
     * @param domainType  域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    List<String> selectValidDomainByType(Integer domainType);

    /**
     * 查询给微信巡查的域名列表
     *
     * @return
     */
    List<String> selectWxPatrol();

    /**
     * 根据域名查询
     *
     * @param domain   域名
     * @return
     */
    DomainDTO selectByDomain(String domain);

    /**
     * 根据策略id 和域名类型查询替换域名
     * @param advertId   广告id
     * @param domainType 域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    String getReplaceDomain(Long advertId, Integer domainType);

    /**
     * 根据域名类型查询有效域名列表
     *
     * @param domainType  域名类型 {@link cn.com.duiba.tuia.risk.center.api.enums.DomainTypeEnum#status}
     * @return
     */
    List<DomainDTO> getValidDomainByType(Integer domainType);

    /**
     * 根据域名策略更新域名到新的策略
     * @param strategyId
     * @param newStrategyId
     * @return
     */
    Integer updateDomainStrategy(Long strategyId, Long newStrategyId);

    /**
     * 根据域名获取数据
     * @param domains
     * @return
     */
    List<DomainDTO> getByDomains(List<String> domains);

    /**
     * 根据域名获取失效的域名列表
     *
     * @param domainDealParam
     * @return
     */
    Set<String> getInvalidDomainParam(DomainDealParam domainDealParam);

}
